//
//  SOMAMoPubNativeLayoutAdapter.m
//  iSoma
//
//  Created by Aman Shaikh on 14.07.16.
//  Copyright © 2016 Smaato Inc. All rights reserved.
//

#import "SOMAMoPubNativeCustomEvent.h"
#import "MPNativeAdConstants.h"
#import "SOMAMoPubNativeAdAdapter.h"
#import "MPNativeAd.h"

#ifdef SOMAUITEST
#import "iSoma.h"
#else
#import <iSoma/iSoma.h>
#endif

@interface SOMAMoPubNativeCustomEvent()
@property SOMANativeAd* somaNativeAd;
@end

@implementation SOMAMoPubNativeCustomEvent
- (void)requestAdWithCustomEventInfo:(NSDictionary *)info{
	NSLog(@"SOMAMoPubNativeLayoutAdapter: requesting ad with custom ad info: %@", info);
	
	if (info == nil) {
		[self.delegate nativeCustomEvent:self didFailToLoadAdWithError:[NSError errorWithDomain:@"SOMAMoPubNativeLayoutAdapterNilInfo" code:400 userInfo:nil]];
		NSLog(@"Please put a valid json in 'CUSTOM EVENT CLASS DATA' section on mopub dashboard e.g. {\"pub\":\"0\",\"ad\":\"3075\"}");
	}
	
	NSString* publisherId = info[@"pub"];
	NSString* adspaceId = info[@"ad"];
	
	if (publisherId == nil || adspaceId == nil) {
		[self.delegate nativeCustomEvent:self didFailToLoadAdWithError:[NSError errorWithDomain:@"SOMAMoPubNativeLayoutAdapterInvalidInfo" code:400 userInfo:nil]];
		NSLog(@"Please put a valid json in 'CUSTOM EVENT CLASS DATA' section on mopub dashboard e.g. {\"pub\":\"0\",\"ad\":\"3075\"}");
	}
	
	
	self.somaNativeAd = [[SOMANativeAd alloc] initWithPublisherId:publisherId adSpaceId:adspaceId];
	self.somaNativeAd.adSettings.httpsOnly = YES;
	__weak SOMAMoPubNativeCustomEvent* weakSelf = self;
	[self.somaNativeAd requestAd:^(SOMANativeAdDTO *dto, NSError *error) {
		if (error != nil) {
			[weakSelf.delegate nativeCustomEvent:self didFailToLoadAdWithError:error];
			NSLog(@"SOMAMoPubNativeLayoutAdapter Request failed: %@", [error localizedDescription]);
			return;
		}
		
		if (dto == nil) {
			[self.delegate nativeCustomEvent:self didFailToLoadAdWithError:[NSError errorWithDomain:@"SOMAMoPubNativeLayoutAdapterInvalidSOMAResponse" code:400 userInfo:nil]];
			NSLog(@"SOMAMoPubNativeLayoutAdapter Received invalid response, please ensure valid publisher id and adspace id");
			return;
		}
		
		NSMutableDictionary* dic = [NSMutableDictionary new];
		dic[kAdTitleKey] = dto.title;
		dic[kAdTextKey] = dto.text;
		dic[kAdIconImageKey] = dto.iconImageURL.absoluteString;
		dic[kAdMainImageKey] = dto.mainImageURL.absoluteString;
		dic[kAdStarRatingKey] = [NSNumber numberWithFloat:dto.starrating];
		dic[kAdCTATextKey] = dto.callToAction;
		dic[kDefaultActionURLKey] = dto.target.absoluteString;
		dic[kImpressionTrackerURLsKey] = dto.beacons;
		SOMAMoPubNativeAdAdapter* adapter = [[SOMAMoPubNativeAdAdapter alloc] init:[dic copy] withDefaultActionURL:dto.target];
		
		dispatch_async(dispatch_get_main_queue(), ^{
			[weakSelf.delegate nativeCustomEvent:self didLoadAd:[[MPNativeAd alloc] initWithAdAdapter:adapter]];
		});
	}];
}
@end
